<template>
  <div class="app-container pageSediment">
    <el-form
      v-show="showSearch"
      ref="queryForm"
      :inline="true"
      :model="queryParams"
      label-width="68px"
    >
      <el-form-item label="科室名称" prop="deptId">
        <el-input
          v-model="queryParams.deptName"
          clearable
          placeholder="请输入科室名称"
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button
          icon="el-icon-search"
          size="mini"
          type="cyan"
          @click="handleQuery"
        >搜索
        </el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
        >重置
        </el-button>
        <el-button
          v-hasPermi="['basis:dept:add']"
          icon="el-icon-plus"
          size="mini"
          type="primary"
          @click="handleAdd"
        >新增
        </el-button>
        <el-button
          v-hasPermi="['basis:dept:edit']"
          :disabled="single"
          icon="el-icon-edit"
          size="mini"
          type="success"
          @click="handleUpdate"
        >修改
        </el-button>
        <el-button
          v-hasPermi="['basis:dept:remove']"
          :disabled="multiple"
          icon="el-icon-delete"
          size="mini"
          type="danger"
          @click="handleDelete"
        >删除
        </el-button>
        <el-button
          :disabled="single"
          icon="el-icon-setting"
          size="mini"
          type="success"
          @click="selectExamDept()"
        >设置检查类型
        </el-button>
      </el-form-item>
    </el-form>

    <el-table
      ref="multipleTable"
      v-loading="loading"
      :data="deptList" border
      stripe tooltip-effect="light" @row-click="handleRowClick"
      @selection-change="handleSelectionChange"
    >
      <el-table-column align="center" type="selection" width="55"/>
      <el-table-column v-if="false" align="center" label="主键ID" prop="id"/>
      <el-table-column v-if="false" :formatter="orgInfoQuery" align="center" label="组织机构" prop="orgId"/>
      <el-table-column v-if="false" align="center" label="院区ID" prop="yardId"/>
      <el-table-column align="left" fixed="left" label="科室名称" min-width="180" prop="deptName" show-overflow-tooltip/>
      <el-table-column align="left" fixed="left" label="科室编码" min-width="160" prop="deptId" show-overflow-tooltip/>
      <el-table-column :formatter="functionType" align="left" label="检查类型" prop="visitType" width="110"/>
      <!--      <el-table-column label="拼音码" align="left" prop="pyCode" width="120" />-->
      <el-table-column align="left" label="具体位置" min-width="400" prop="address" show-overflow-tooltip/>
      <!--      <el-table-column
              label="操作"
              align="center"
              class-name="small-padding fixed-width"
            >
              <template slot-scope="scope">
                <el-button
                  size="mini"
                  type="text"
                  icon="el-icon-edit"
                  @click="handleUpdate(scope.row)"
                  v-hasPermi="['basis:dept:edit']"
                  >修改</el-button
                >
                <el-button
                  size="mini"
                  type="text"
                  icon="el-icon-delete"
                  @click="handleDelete(scope.row)"
                  v-hasPermi="['basis:dept:remove']"
                  >删除</el-button
                >
              </template>
            </el-table-column>-->
    </el-table>

    <pagination
      v-show="total > 0"
      :limit.sync="queryParams.pageSize"
      :page.sync="queryParams.pageNum"
      :total="total"
      @pagination="getList"
    />

    <!-- 添加或修改部门信息对话框 -->
    <el-dialog v-dialogDrag :title="title" :visible.sync="open" append-to-body width="500px">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="组织机构" prop="orgId">
          <el-select v-model="form.orgId" clearable placeholder="请选择机构">
            <el-option :key="0" :label="'全部'" :value="''"/>
            <el-option
              v-for="item in orgList"
              :key="item.id"
              :label="item.orgName"
              :value="item.orgCode"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="院区" prop="yardId">
          <el-select v-model="form.yardId" clearable placeholder="请选择院区">
            <el-option :key="0" :label="'全部'" :value="''"/>
            <el-option
              v-for="item in yardList"
              :key="item.id"
              :label="item.yardName"
              :value="item.yardCode"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="科室编码" prop="deptId">
          <el-input v-model="form.deptId" placeholder="请输入部门编码"/>
        </el-form-item>
        <el-form-item label="科室名称" prop="deptName">
          <el-input v-model="form.deptName" placeholder="请输入部门名称"/>
        </el-form-item>
        <el-form-item label="具体位置" prop="address">
          <el-input v-model="form.address" placeholder="请输入具体位置" type="textarea"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <!--设置科室类型-->
    <el-dialog v-dialogDrag :visible.sync="dialogVisible" title="设置" width="30%">
      <span>
        <div class="block">
          <span class="demonstration">检查类型:</span>
          <el-select v-model="optest"
                     allow-create
                     placeholder=""
          >
            <el-option v-for="item in options "
                       :key="item.typeCode"
                       :label="item.typeName"
                       :value="item.typeCode"
            >
            </el-option>
          </el-select>
        </div>
      </span>
      <span slot="footer" class="dialog-footer">
        <el-button @click="dialogVisible = false">取 消</el-button>
        <el-button type="primary" @click="UpdateExamDept"
        >确 定</el-button
        >
      </span>
    </el-dialog>
  </div>
</template>

<script>
import {
  listDept,
  getDept,
  delDept,
  addDept,
  updateDept,
  exportDept,
  getExamDept,
  addExamDept
} from '@/api/basis/dept'
import { listExamtype } from '@/api/basis/examtype'
import { listLocationInfo } from '@/api/basis/locationInfo'
import { listOrg } from '@/api/system/org'
import { listYard } from '@/api/basis/yard'
import vPinyin from '@/utils/vue-py'//拼音码转换
export default {
  name: 'Examdept',
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 部门信息表格数据
      deptList: [],
      // 弹出层标题
      title: '',
      // 部门类型字典
      deptTypeOptions: [],
      // 是否显示弹出层
      open: false,
      //是否打开检查类型对话框
      dialogVisible: false,
      //机构
      orgList: [],
      //院区
      yardList: [],
      //楼栋
      locationList: [],
      //楼层总数
      maxfloorNum: 0,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 20,
        orgId: null,
        yardId: null,
        deptId: null,
        deptType: 3,
        locationBuildingId: null,
        locationFloorId: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        orgId: [
          { required: true, message: '组织机构编码不能为空', trigger: 'blur' }
        ],
        yardId: [
          { required: true, message: '院区不能为空', trigger: 'blur' }
        ],
        deptId: [
          { required: true, message: '科室编码不能为空', trigger: 'blur' }
        ],
        deptName: [
          { required: true, message: '部门名称不能为空', trigger: 'blur' }
        ],
        deptType: [
          { required: true, message: '科室类型不能为空', trigger: 'change' }
        ],

        address: [
          { required: true, message: '具体位置不能为空', trigger: 'blur' }
        ]
      },
      optest: [],
      props: {
        multiple: true,
        value: 'typeCode',
        label: 'typeName'
      },
      options: []
    }
  },
  watch: {},
  mounted() {
    console.log('///////' + this.value)
    this.getDicts('dept_type').then((response) => {
      this.deptTypeOptions = response.data
    })
    this.getList()
    listOrg({ isValid: 1 }).then((response) => {
      this.orgList = response.rows
    })
    listYard({ isValid: 1 }).then((response) => {
      this.yardList = response.rows
    })
    this.LocationInfoLists()
    listExamtype().then(response => {
      //  console.log(response);
      this.options = response.rows
      // console.log(this.options)
    })
  },
  methods: {
    handleRowClick(row, column, event) {
      this.$refs.multipleTable.toggleRowSelection(row)
    },
    /** 查询部门信息列表 */
    getList() {
      this.loading = true
      listDept(this.queryParams).then((response) => {
        this.deptList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    /**组织机构信息*/
    orgInfoQuery(row, column) {
      let id = row.orgId
      for (var i = 0; i < this.orgList.length; i++) {
        if (id == this.orgList[i].orgCode) {
          return this.orgList[i].orgName
        }
      }
    },
    // 部门类型字典翻译
    deptTypeFormat(row, column) {
      return this.selectDictLabel(this.deptTypeOptions, row.deptType)
    },
    //楼栋信息
    LocationInfoLists() {
      listLocationInfo({}).then((response) => {
        this.locationList = response.rows
      })
    },
    floorOptions(val) {
      // console.log(val);
      this.locationList.forEach((item) => {
        if (val == item.id) {
          //this.form.locationFloorId = item.id;
          this.maxfloorNum = item.floorNumber
        }
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        orgId: null,
        yardId: null,
        deptId: null,
        deptName: null,
        pyCode: null,
        deptType: 1,
        locationBuildingId: null,
        locationFloorId: null,
        address: null,
        updatedByName: null
      }
      this.maxfloorNum = 0
      this.resetForm('form')
    },
    functionType(row, column) {
      // console.log(row.examType);
      /*let name = ''
      if (row.examType.length > 0 && row.examType[0] != null) {
        row.examType.forEach(item => {
          name += item.typeName + ','

        })
        name = name.substring(0, name.lastIndexOf(','))
      }
      return name*/
      let temp = this.options.find(item => item.typeCode + '' === row.visitType + '')
      if (temp) {
        return temp.typeName
      }
      return ''
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加科室信息'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids
      getDept(id).then((response) => {
        this.form = response.data
        this.open = true
        this.title = '修改科室信息'
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate((valid) => {
        //拼音码自动转换
        if (this.form.deptName != null && this.form.deptName != '') {
          this.form.pyCode = vPinyin.chineseToPinYin(this.form.deptName)
        }
        this.form.deptType = 3
        if (valid) {
          if (this.form.id != null) {
            updateDept(this.form).then((response) => {
              this.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addDept(this.form).then((response) => {
              this.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids
      this.$confirm(
        '是否确认删除科室信息编号为"' + ids + '"的数据项?',
        '警告',
        {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }
      )
        .then(function() {
          return delDept(ids)
        })
        .then(() => {
          this.getList()
          this.msgSuccess('删除成功')
        })
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$confirm('是否确认导出所有科室信息数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return exportDept(queryParams)
        })
        .then((response) => {
          this.download(response.msg)
        })
    },
    selectExamDept() {
      const id = this.ids[0]
      var that = this
      that.dialogVisible = true
      let temp = this.deptList.find(item => item.id === id)
      if (temp) {
        that.optest = temp.visitType
        that.dialogVisible = true
      }
      /*      getExamDept(id).then((response) => {
               //打开类型检查对话框
               that.dialogVisible = true;
              that.optest=[];
             console.log(response.data)
              if(response.data.length>0&&response.data[0]!=null){
                response.data.forEach( item => {
                 that.optest.push(item.typeCode)
              })
              }
            });*/
    },
    //修改检查类型关联信息
    UpdateExamDept() {
      const id = this.ids
      updateDept({
        id: id + '',
        visitType: this.optest
      }).then((response) => {
        this.dialogVisible = false
        this.$message('修改成功！')
        this.getList()
      })
    }
  }
}
</script>
